==> kuroo-0.90.5_p20180410.tar.xz: kuroo-0.90.5_p20180410/src/intro/introdlg.h <==
/***************************************************************************
*   Copyright (C) 2004 by shiva                                           *
*   shiva@Katmandu                                                        *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/

#ifndef INTRODLG_H
#define INTRODLG_H

#include <QWizard>
#include "ui_intro.h"

/**
 * @class IntroDlg
 * @short Kuroo introductory wizard.
 */
class IntroDlg : public QWizard, public Ui::Intro
{
Q_OBJECT
public:
	IntroDlg( /*QWidget* parent = 0 */);
	~IntroDlg();

private:
	void 	accept();

};

#endif

==> kuroo-1.2.4.tar.xz: kuroo-1.2.4/src/intro/introdlg.h <==
/***************************************************************************
*   Copyright (C) 2004 by shiva                                           *
*   shiva@Katmandu                                                        *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/

#ifndef INTRODLG_H
#define INTRODLG_H

#include <QWizard>
#include <qobjectdefs.h>  // for Q_OBJECT
#include <qstring.h>      // for QString
#include <qwizard.h>      // for QWizard

#include "ui_intro.h"     // for Intro


/**
 * @class IntroDlg
 * @short Kuroo introductory wizard.
 */
class IntroDlg : public QWizard, public Ui::Intro
{
Q_OBJECT
public:
	IntroDlg( QWidget* parent = nullptr );
	~IntroDlg();

private:
	void 	accept() override;

};

#endif
